#include "fihm.h"
#include "ui_fihm.h"
#include "liaisonRS232.h"
#include <QtSerialPort/QSerialPort>
#include <QObject>

fihm::fihm(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::fihm)
{
    ui->setupUi(this);
    serial = new QSerialPort;
    liairs232 = new LiaisonRS232;
    connect(liairs232,SIGNAL(sigEnvoyerOctet(QByteArray)), this, SLOT(slt_receptionOctet(QByteArray)));
}


//---------------------Initialisation port série---------------------//

    void fihm::init()
    {

        serial->setPortName(PORT);
        serial->setBaudRate(QSerialPort::Baud9600);
        serial->setDataBits(QSerialPort::Data8);
        serial->setParity(QSerialPort::Parity);
        serial->setStopBits(QSerialPort::OneStop);
        serial->setFlowControl(QSerialPort::NoFlowControl);
        serial->open(QSerialPort::ReadWrite);

    }


//---------------------Reception des trames de la station météo---------------------//

    void fihm::slt_receptionOctet(QByteArray data)
    {
        bool ok = false;
        int i = 0, j = 0;
        int itrame[20];
        QString trame = "";

        for(j = 0; j < 20; j++)
        {
            itrame[j] = data[j];
            trame += QString::number(itrame[j]) + "  ";
        }

        do{
            if(data[i] == 255)
            {
               i++;
                if(data[i] == 255)
                {
                    ok = true;

                    i++;

                    int direction = 0, gustWindSpeed = 0, gustWindSpeedDixieme = 0, averageWindSpeed = 0, averageWindSpeedDixieme = 0;
                    int THBTemp = 0, THBTempDixieme = 0, THBHum = 0;
                    int minute = 0, heure = 0;
                    int rainCurrent = 0, rainTotalDixieme = 0, rainTotal = 0;
                    int MushTemp = 0, MushTempDixieme = 0, MushHum = 0;
                    switch(data[i])
                    {
                    case 0:                                 //Wind
                        i+=2;
                        direction += (data[i] & 0x00);
                        direction += (data[i] >> 4)*10;
                        i++;
                        direction += (data[i] & 0x00);
                        ui->lnedWindDirection->setText(QString::number(direction) + '?');

                        gustWindSpeedDixieme += (data[i] >> 4);
                        i++;
                        gustWindSpeed += (data[i] & 0x00);
                        gustWindSpeed += (data[i] >> 4)*10;
                        ui->lnedGustWindSpeed->setText(QString::number(gustWindSpeed) + "," + QString::number(gustWindSpeedDixieme));

                        i++;
                        averageWindSpeedDixieme += (data[i] & 0x00);
                        averageWindSpeed += (data[i] >> 4);
                        averageWindSpeed += (data[i] >> 4)*10;
                        ui->lnedAverageWindSpeed->setText(QString::number(averageWindSpeed) + "," + QString::number(averageWindSpeedDixieme));
                        break;

                    case 1:                                 //Rain
                        i+=2;
                        rainCurrent += (data[i] & 0x01);
                        rainCurrent += (data[i] >> 4)*10;
                        i++;
                        rainCurrent += (data[i] & 0x01)*100;
                        ui->lnedRainCurrent->setText(QString::number(rainCurrent) + " mm/h");
                        break;

                    case 3:                                 //Mushroom
                        i+=2;
                        MushTempDixieme = (data[i] & 0x03);
                        MushTemp += (data[i] >> 4);
                        i++;
                        MushTemp += (data[i] & 0x03)*10;
                        MushTemp += (data[i] & 0x03)*100;
                        ui->lnedMushTemp->setText(QString::number(MushTemp) + "," + QString::number(MushTempDixieme) + '?');

                        i++;
                        MushHum += (data[i] & 0x03);
                        MushHum += (data[i] >> 4)*10;
                        ui->lnedMushHum->setText(QString::number(MushHum) +"%");
                        break;

                    case 6:                                 //New THB
                        i+=2;
                        THBTempDixieme = (data[i] & 0x06);
                        THBTemp += (data[i] >> 4);
                        i++;
                        THBTemp += (data[i] & 0x06)*10;
                        THBTemp += (data[i] & 0x06)*100;
                        if(THBTemp != 0)
                            ui->lnedTHBTemp->setText(QString::number(THBTemp) + "," + QString::number(THBTempDixieme) + '?');

                        i++;
                        THBHum += (data[i] & 0x6F);
                        THBHum += (data[i] >> 4)*10;
                        if(THBHum != 0)
                            ui->lnedTHBHum->setText(QString::number(THBHum) +"%");
                        break;
                    case 14:                                //Minutes
                        i++;
                        minute += (data[i] & 0x0E);
                        minute += (data[i] >> 4)*10;
                        ui->lnedMinutes->setText(QString::number(minute) + "min");
                        break;

                    case 15:                                //Clock
                        i++;
                        heure += (data[i] & 0x0F);
                        heure += (data[i] >> 4)*10;
                        ui->lnedHeure->setText(QString::number(heure) + "h");
                        break;
                    }
                }
            }
            i++;
        }while(!ok);
    }



fihm::~fihm()
{
    delete ui;
}
